# Py - Ayiin Library
<p align="center">
  <img src="https://telegra.ph//file/897863d5713e6b0b5ec58.jpg">
</p>


### Core library of [py-Ayiin](https://github.com/AyiinXd)
Pyrogram And Telethon based for your userbot.


#
[![PyPI - Version](https://img.shields.io/pypi/v/py-Ayiin?style=round)](https://pypi.org/project/py-Ayiin)    
[![PyPI - Downloads](https://img.shields.io/pypi/dm/py-Ayiin?label=DOWNLOADS&style=round)](https://pypi.org/project/py-Ayiin/)    
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/AyiinXd/AyiinXd/graphs/commit-activity)
[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/AyiinXd/AyiinXd)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)

# Installation
```bash
pip3 install -U py-Ayiin
```
#

## Made with ✨ by

[![Ayiin](https://img.shields.io/static/v1?label=Github&message=AyiinXd&color=critical)](https://github.com/AyiinXd)   
[![Ayiin](https://img.shields.io/static/v1?label=Telegram&message=AyiinXd&color=aqua)](https://t.me/AyiinXd)
#
# License
[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](LICENSE)   
py-Ayiin is licensed under [GNU General Public License](https://www.gnu.org/licenses/agpl-3.0.html) v3 or later.
#
# Credits
*  [AyiinXd](https://github.com/AyiinXd) for [py-Ayiin](https://github.com/AyiinXd)
*  [Dan](https://github.com/delivrance) for [Pyrogram](https://github.com/pyrogram/pyrogram)
*  [Lonami](https://github.com/LonamiWebs/) for [Telethon](https://github.com/LonamiWebs/Telethon)
#